{% extends "project/databases/_detail_overview.html" %}
{% load i18n sizeformat %}

{% block connection_info %}
    <h4>{% trans "Connection Information" %}</h4>
    <hr class="header_rule">
    <dl class="dl-horizontal">
      {% with instance.host as host %}
          <dt>{% trans "Host" %}</dt>
          {% if not host %}
              <dd>{% trans "Not Assigned" %}</dd>
          {% else %}
              <dd>{{ host }}</dd>
              <dt>{% trans "Connection Examples" %}</dt>
              <dd>http://{{ host }}:8091</dd>
          {% endif %} <!-- ends else block -->
      {% endwith %}
    </dl>
{% endblock %}
